#
# spec file for package habootstrap-formula
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines
%define fname cluster
%define fdir  %{_datadir}/salt-formulas

Name:           habootstrap-formula
Version:        0.2.4
Group:          System/Packages
Release:        lp151.7.1
Summary:        HA cluster (crmsh) deployment salt formula

License:        Apache-2.0
Url:            https://github.com/SUSE/%{name}
Source0:        %{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires:       salt-shaptools

# TODO: Include this dependency back when is it available on 15-SP1.
# On SLE/Leap 15-SP1 and TW requires the new salt-formula configuration location.
#%if ! (0%{?sle_version:1} && 0%{?sle_version} < 150100)
#Requires:       salt-formulas-configuration
#%endif


%description
HA cluster salt deployment formula. This formula is capable to perform
the HA cluster bootstrap actions (init, join, remove) using standalone salt
or via SUSE Manager formulas with forms, available on SUSE Manager 4.0.

%if ! (0%{?sle_version:1} && 0%{?sle_version} < 150100)
The formula is installed on the /usr/share/salt-formulas location, so in order
to use it, make sure to map this directory into the file_roots of your
salt master/minion salt standalone configuration or into the SUSE Manager
salt configuration file (when using SUSE Manager formulas with forms).
%endif

%prep
%setup -q

%build

%install

# before SUMA 4.0/15-SP1, install on the standard Salt Location.
%if 0%{?sle_version:1} && 0%{?sle_version} < 150100

mkdir -p %{buildroot}/srv/salt/
cp -R %{fname} %{buildroot}/srv/salt

%else

# On SUMA 4.0/15-SP1, a single shared directory will be used.
mkdir -p %{buildroot}%{fdir}/states/%{fname}
mkdir -p %{buildroot}%{fdir}/metadata/%{fname}
cp -R %{fname} %{buildroot}%{fdir}/states
cp -R form.yml %{buildroot}%{fdir}/metadata/%{fname}
if [ -f metadata.yml ]
then
  cp -R metadata.yml %{buildroot}%{fdir}/metadata/%{fname}
fi

%endif

%if 0%{?sle_version:1} && 0%{?sle_version} < 150100

%files
%defattr(-,root,root,-)
%if 0%{?sle_version} < 120300
%doc README.md LICENSE
%else
%doc README.md
%license LICENSE
%endif
/srv/salt/%{fname}

%dir %attr(0755, root, salt) /srv/salt

%else

%files
%defattr(-,root,root,-)
%doc README.md
%license LICENSE
%dir %{fdir}
%dir %{fdir}/states
%dir %{fdir}/metadata
%{fdir}/states/%{fname}
%{fdir}/metadata/%{fname}

%dir %attr(-, root, root) %{fdir}
%dir %attr(-, root, root) %{fdir}/states
%dir %attr(-, root, root) %{fdir}/metadata

%endif

%changelog
* Mon Jul 22 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version bump 0.2.4
  * Fix issue with file permissions during package installation in
    /usr/share/salt-formulas
    (boo#1142306)
* Fri Jul  5 2019 Dario Maiocchi <dmaiocchi@suse.com>
- Make pkg.install more resilient, allowing retries during install
* Tue Jul  2 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Version bump 0.2.2
  * Change the salt-formula directories permissions to 0750 to avoid
    conflicts with the package salt-standalone-formulas-configuration.
  * Correct the required package name to
    salt-standalone-formulas-configuration
* Tue Jun 11 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.2.1 with fixed spec files. Now the package
  is available in all SLE12 and SLE15 versions (boo#1137989, jsc#SLE-4031)
* Fri May 31 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Version bump 0.2.0
  * Include the salt-formulas-configuration dependency on
    SLE/Leap 15-SP1 and higher. This package configures the shared salt
    formulas location (/usr/share/salt-formulas) to be used by SUMA 4.0
    or salt in standalone mode.
  * Drops the habootstrap-formula-suma package, as the forms metadata
    will be available only on SUMA 4.0 using the shared location.
* Thu May 16 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Remove network repository installation
* Thu Apr 25 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Changed requires from salt-saphana to salt-shaptools.
* Tue Feb 19 2019 dakechi@suse.com
- Update to version 1.0.0+git.1550242845.0e69ab8:
  * Allow pre-configured packages
  * Update package installation to use ha pattern for SUSE distros
  * Update join_timer parameter description
  * Allow custom timer before cluster join
  * Improve pre validation state to check the proper parameters
  * Create suma form and adapt states to that
  * Add new feature to the formula: - Ntp connection - SSH keys management - Watchdog - Mandatory pacakges and RA packages
  * Add new options to configure the cluster in creation
  * Update ha formula to use crmsh salt code
  * Updated README and added comment about NET_IP in Vagrantfile
- Consolidate the SUMA specific package into one .spec file
* Fri Sep 14 2018 kgronlund@suse.com
- Update to version 1.0.0+git.1536931866.e47f6ce:
  * Pillar data has to be defined in a separate SLS
  * Revised pillar data layout to make usage simpler
  * Drop extraneous dash in join args
  * Set group in metadata.yml
* Thu Sep  6 2018 kgronlund@suse.com
- Update to version 1.0.0+git.1536240306.8442de8:
  * Add metadata.yml
* Thu Sep  6 2018 kgronlund@suse.com
- Initial version
